@@ -197,8 +197,8 @@ class Parser():
 
     def request(self, deviceType, dataType, repeat, interval):
 
-        drone = Drone(True, True, True, True, True)
-        #drone = Drone()
+        #drone = Drone(True, True, True, True, True)
+        drone = Drone()
         if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
@@ -217,8 +217,8 @@ class Parser():
 
     def command(self, commandType, option = 0):
 
-        drone = Drone(True, True, True, True, True)
-        #drone = Drone()
+        #drone = Drone(True, True, True, True, True)
+        drone = Drone()
         if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
@@ -229,8 +229,8 @@ class Parser():
 
     def control(self, roll, pitch, yaw, throttle, timeMs):
 
-        drone = Drone(True, True, True, True, True)
-        #drone = Drone()
+        #drone = Drone(True, True, True, True, True)
+        drone = Drone()
         if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
@@ -242,8 +242,8 @@ class Parser():
 
     def controlPosition(self, x, y, z, velocity, heading, rotationalVelocity):
 
-        drone = Drone(True, True, True, True, True)
-        #drone = Drone()
+        #drone = Drone(True, True, True, True, True)
+        drone = Drone()
         if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
@@ -255,8 +255,8 @@ class Parser():
 
     def lightModeRgb(self, strLightPart, strLightMode, interval, r, g, b):
 
-        drone = Drone(True, True, True, True, True)
-        #drone = Drone()
+        #drone = Drone(True, True, True, True, True)
+        drone = Drone()
         if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
@@ -305,8 +305,8 @@ class Parser():
 
     def lightModeSingle(self, strLightPart, strLightMode, interval):
 
-        drone = Drone(True, True, True, True, True)
-        #drone = Drone()
+        #drone = Drone(True, True, True, True, True)
+        drone = Drone()
         if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
@@ -352,8 +352,8 @@ class Parser():
 
     def buzzer(self, target, hz, time):
 
-        drone = Drone(True, True, True, True, True)
-        #drone = Drone()
+        #drone = Drone(True, True, True, True, True)
+        drone = Drone()
         if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
@@ -380,8 +380,8 @@ class Parser():
 
     def vibrator(self, target, on, off, total):
 
-        drone = Drone(True, True, True, True, True)
-        #drone = Drone()
+        #drone = Drone(True, True, True, True, True)
+        drone = Drone()
         if drone.open() == False:
             print(Fore.RED + "* Error : Unable to open serial port." + Style.RESET_ALL)
             sys.exit(1)
@@ -491,8 +491,8 @@ class Parser():
                 Fore.WHITE + "{0:8}".format(state.modeControlFlight.name) +
                 Fore.WHITE + "{0:8}".format(state.modeMovement.name) +
                 Fore.WHITE + "{0:8}".format(state.headless.name) +
-                Fore.CYAN + "{0:8}".format(state.controlSpeed.name) +
-                Fore.CYAN + "{0:10}".format(state.sensorOrientation) +
+                Fore.CYAN + "{0:8}".format(state.controlSpeed) +
+                Fore.CYAN + "{0:10}".format(state.sensorOrientation.name) +
                 Fore.GREEN + "{0:5}".format(state.battery) + Style.RESET_ALL)
                 
 
